==> bibledit-0.7.tar.gz: bibledit-0.7/src/dialogreplacing.h <==
/*
** Copyright (C) 2003 The Free Software Foundation.
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**  
*/

#ifndef INCLUDED_DIALOGREPLACING_H
#define INCLUDED_DIALOGREPLACING_H

#include <gtk/gtk.h>
#include "scripture.h"
#include "ustring.h"


class ReplacingDialog
{
public:
  ReplacingDialog (const string & projectname, const vector < string > &references_in, const ustring & searchword, const ustring & replaceword, bool casesensitive);
    virtual ~ ReplacingDialog ();
  virtual int run ();
protected:
private:
    GtkWidget * replacedialog;
  GtkWidget *dialog_vbox1;
  GtkWidget *referencelabel;
  GtkWidget *vbox1;
  GtkWidget *label1;
  GtkWidget *scrolledwindow4;
  GtkWidget *textview1;
  GtkWidget *label2;
  GtkWidget *scrolledwindow5;
  GtkWidget *textview2;
  GtkWidget *hbox3;
  GtkWidget *yesbutton;
  GtkWidget *nobutton;
  GtkWidget *allbutton;
  GtkWidget *alignment1;
  GtkWidget *hbox4;
  GtkWidget *image1;
  GtkWidget *label3;
  GtkWidget *cancelbutton;
  GtkWidget *dialog_action_area1;
    vector < string > references;
  unsigned int referencepointer;
  bool mycasesensitive;
  GtkTextTag *tag1;
  GtkTextTag *tag2;
  GtkTextBuffer *textbuffer1;
  GtkTextBuffer *textbuffer2;
  void set_gui ();
  void accept_change ();
  Scripture scripture;
  ustring searchfor;
  ustring replacewith;
  static void replacedialog_on_cancelbutton_clicked (GtkButton * button, gpointer user_data);
  void on_cancelbutton_clicked ();
  static void replacedialog_on_yesbutton_clicked (GtkButton * button, gpointer user_data);
  void on_yesbutton_clicked ();
  static void replacedialog_on_nobutton_clicked (GtkButton * button, gpointer user_data);
  void on_nobutton_clicked ();
  static void replacedialog_on_allbutton_clicked (GtkButton * button, gpointer user_data);
  void on_allbutton_clicked ();
};


#endif

==> bibledit-0.9.tar.gz: bibledit-0.9/src/dialogreplacing.h <==
/*
** Copyright (C) 2003-2005 The Free Software Foundation.
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**  
*/

#ifndef INCLUDED_DIALOGREPLACING_H
#define INCLUDED_DIALOGREPLACING_H

#include <gtk/gtk.h>
#include "scripture.h"
#include "ustring.h"
#include "usfm.h"


class ReplacingDialog
{
public:
  ReplacingDialog (Configuration& configuration, const vector <string>& references_in, Usfm * usfm);
  virtual ~ ReplacingDialog ();
  virtual int run ();
protected:
private:
  GtkWidget * replacedialog;
  GtkWidget *dialog_vbox1;
  GtkWidget *referencelabel;
  GtkWidget *vbox1;
  GtkWidget *label1;
  GtkWidget *scrolledwindow4;
  GtkWidget *textview1;
  GtkWidget *label2;
  GtkWidget *scrolledwindow5;
  GtkWidget *textview2;
  GtkWidget *hbox3;
  GtkWidget *yesbutton;
  GtkWidget *nobutton;
  GtkWidget *allbutton;
  GtkWidget *alignment1;
  GtkWidget *hbox4;
  GtkWidget *image1;
  GtkWidget *label3;
  GtkWidget *cancelbutton;
  GtkWidget *dialog_action_area1;
  vector < string > references;
  unsigned int referencepointer;
  bool mycasesensitive;
  GtkTextTag *tag1;
  GtkTextTag *tag2;
  GtkTextBuffer *textbuffer1;
  GtkTextBuffer *textbuffer2;
  void set_gui ();
  void accept_change ();
  Scripture scripture;
  ustring searchfor;
  ustring replacewith;
  Usfm * myusfm;
  static void replacedialog_on_cancelbutton_clicked (GtkButton * button, gpointer user_data);
  void on_cancelbutton_clicked ();
  static void replacedialog_on_yesbutton_clicked (GtkButton * button, gpointer user_data);
  void on_yesbutton_clicked ();
  static void replacedialog_on_nobutton_clicked (GtkButton * button, gpointer user_data);
  void on_nobutton_clicked ();
  static void replacedialog_on_allbutton_clicked (GtkButton * button, gpointer user_data);
  void on_allbutton_clicked ();
};


#endif
